==> jc-1.4.0.tar.gz: java/util/Collections__24SynchronizedMap__242.h <==
// final class java.util.Collections$SynchronizedMap$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 49021d874f7b140b java_util_Collections__24SynchronizedCollection
// @dep_class 74b75fa1de994b73 java_util_Collections__24SynchronizedMap__242
// @dep_class b10c6bbe8b325c8b java_util_Collections__24SynchronizedSet

// header file dependencies
// @dep_header java_util_Collections__24SynchronizedSet

#include "java/util/Collections__24SynchronizedSet.h"

#ifndef _JC_java_util_Collections__24SynchronizedMap__242_H_
#define _JC_java_util_Collections__24SynchronizedMap__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collections__24SynchronizedMap$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedMap__242$sub_refs	_jc_java_util_Collections__24SynchronizedMap__242$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__242$sub_nonrefs	_jc_java_util_Collections__24SynchronizedMap__242$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__242$refs	_jc_java_util_Collections__24SynchronizedMap__242$refs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__242$nonrefs	_jc_java_util_Collections__24SynchronizedMap__242$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__242$object	_jc_java_util_Collections__24SynchronizedMap__242$object;

typedef const struct _jc_java_util_Collections__24SynchronizedMap__242$vmethods	_jc_java_util_Collections__24SynchronizedMap__242$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedMap__242$vtable	_jc_java_util_Collections__24SynchronizedMap__242$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedMap__242$vtype	_jc_java_util_Collections__24SynchronizedMap__242$vtype;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedMap__242$method$_init$dd0bd3633c45a9cb(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__242$object *, struct _jc_java_util_Collections__24SynchronizedMap$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedMap__242$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__242$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__242$method_info$iterator$3cc91493d50f531c;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedMap__242$vmethods {
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__242$object *);
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedMap__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedCollection$vmethods	java_util_Collections__24SynchronizedCollection;
	_jc_java_util_Collections__24SynchronizedSet$vmethods	java_util_Collections__24SynchronizedSet;
	_jc_java_util_Collections__24SynchronizedMap__242$vmethods	java_util_Collections__24SynchronizedMap__242;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedMap__242$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedMap__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedMap__242$sub_refs {
	struct _jc_java_util_Collections__24SynchronizedMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedMap__242$refs {
    _jc_java_util_Collections__24SynchronizedMap__242$sub_refs	java_util_Collections__24SynchronizedMap__242;
    _jc_java_util_Collections__24SynchronizedSet$sub_refs	java_util_Collections__24SynchronizedSet;
    _jc_java_util_Collections__24SynchronizedCollection$sub_refs	java_util_Collections__24SynchronizedCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedMap__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedMap__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedCollection$sub_nonrefs	java_util_Collections__24SynchronizedCollection;
    _jc_java_util_Collections__24SynchronizedSet$sub_nonrefs	java_util_Collections__24SynchronizedSet;
    _jc_java_util_Collections__24SynchronizedMap__242$sub_nonrefs	java_util_Collections__24SynchronizedMap__242;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedMap__242$object {
	_jc_java_util_Collections__24SynchronizedMap__242$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedMap__242$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedMap__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedMap__242$vtype _jc_java_util_Collections__24SynchronizedMap__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedMap__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedMap__242$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedMap__242_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24SynchronizedMap__242.h <==
// final class java.util.Collections$SynchronizedMap$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 49021d874f7b140b java_util_Collections__24SynchronizedCollection
// @dep_class 74b75fa1de994b73 java_util_Collections__24SynchronizedMap__242
// @dep_class b10c6bbe8b325c8b java_util_Collections__24SynchronizedSet

// header file dependencies
// @dep_header java_util_Collections__24SynchronizedSet

#include "java/util/Collections__24SynchronizedSet.h"

#ifndef _JC_java_util_Collections__24SynchronizedMap__242_H_
#define _JC_java_util_Collections__24SynchronizedMap__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collections__24SynchronizedMap$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedMap__242$sub_refs	_jc_java_util_Collections__24SynchronizedMap__242$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__242$sub_nonrefs	_jc_java_util_Collections__24SynchronizedMap__242$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__242$refs	_jc_java_util_Collections__24SynchronizedMap__242$refs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__242$nonrefs	_jc_java_util_Collections__24SynchronizedMap__242$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedMap__242$object	_jc_java_util_Collections__24SynchronizedMap__242$object;

typedef const struct _jc_java_util_Collections__24SynchronizedMap__242$vmethods	_jc_java_util_Collections__24SynchronizedMap__242$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedMap__242$vtable	_jc_java_util_Collections__24SynchronizedMap__242$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedMap__242$vtype	_jc_java_util_Collections__24SynchronizedMap__242$vtype;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedMap__242$method$_init$dd0bd3633c45a9cb(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__242$object *, struct _jc_java_util_Collections__24SynchronizedMap$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedMap__242$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__242$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedMap__242$method_info$iterator$3cc91493d50f531c;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedMap__242$vmethods {
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedMap__242$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedMap__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedCollection$vmethods	java_util_Collections__24SynchronizedCollection;
	_jc_java_util_Collections__24SynchronizedSet$vmethods	java_util_Collections__24SynchronizedSet;
	_jc_java_util_Collections__24SynchronizedMap__242$vmethods	java_util_Collections__24SynchronizedMap__242;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedMap__242$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedMap__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedMap__242$sub_refs {
	struct _jc_java_util_Collections__24SynchronizedMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedMap__242$refs {
    _jc_java_util_Collections__24SynchronizedMap__242$sub_refs	java_util_Collections__24SynchronizedMap__242;
    _jc_java_util_Collections__24SynchronizedSet$sub_refs	java_util_Collections__24SynchronizedSet;
    _jc_java_util_Collections__24SynchronizedCollection$sub_refs	java_util_Collections__24SynchronizedCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedMap__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedMap__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedCollection$sub_nonrefs	java_util_Collections__24SynchronizedCollection;
    _jc_java_util_Collections__24SynchronizedSet$sub_nonrefs	java_util_Collections__24SynchronizedSet;
    _jc_java_util_Collections__24SynchronizedMap__242$sub_nonrefs	java_util_Collections__24SynchronizedMap__242;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedMap__242$object {
	_jc_java_util_Collections__24SynchronizedMap__242$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedMap__242$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedMap__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedMap__242$vtype _jc_java_util_Collections__24SynchronizedMap__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedMap__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedMap__242$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedMap__242_H_ */
